TODO: replace this with manifests

NOTE: generalized RDF support is OPTIONAL.

## Positive cases

- `pos_001` - single frame, a set of triples that features all possible terms in any position. Prefix table disabled.
- `pos_002` - single frame, a set of triples that features all possible terms in any position and repeated across one frame.
- `pos_003` - multiple frames (3), repeated terms across frames. Prefix table disabled.
- `pos_004` - multiple frames (3), repeated terms across frames. Prefix table enabled.
- `pos_005` - multiple frames (4), repeated terms across frames, all lookup tables filled and reused. Prefix table enabled.